@@ -1,6 +1,6 @@
 package Reflex::Role::Timeout;
 BEGIN {
-  $Reflex::Role::Timeout::VERSION = '0.070';
+  $Reflex::Role::Timeout::VERSION = '0.071';
 }
 use Reflex::Role;
 use Scalar::Util qw(weaken);
@@ -8,11 +8,11 @@ use Scalar::Util qw(weaken);
 attribute_parameter delay       => "delay";
 attribute_parameter auto_start  => "auto_start";
 
-method_parameter    method_stop   => qw( stop name _ );
-method_parameter    method_start  => qw( start name _ );
-method_parameter    method_reset  => qw( reset name _ );
+method_parameter    method_stop   => qw( stop delay _ );
+method_parameter    method_start  => qw( start delay _ );
+method_parameter    method_reset  => qw( reset delay _ );
 
-callback_parameter  cb_timeout    => qw( on name done );
+callback_parameter  cb_timeout    => qw( on delay done );
 
 role {
 	my $p = shift;
@@ -98,7 +98,7 @@ Reflex::Role::Timeout - set a wakeup callback for a relative delay
 
 =head1 VERSION
 
-version 0.070
+version 0.071
 
 =head1 SYNOPSIS
 
